# pyautoeasy

pyautoeasy is wrapper around the famous [pyautogui](https://pypi.org/project/PyAutoGUI/) library. 

pyautoeasy makes it easy to grab different points in the screen and give them meaningful variable names.
After this it generates a sample program with these generated points as high level objects that can be used easily to do various operations like click, type etc. 


Todo:
- Improve docs
- create command line utility
- packaging